==> huaweicloudsdkworkspace-3.1.133-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_instances_status_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstancesStatusResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'statics': 'list[InstanceStatusStatistics]'
    }

    attribute_map = {
        'statics': 'statics'
    }

    def __init__(self, statics=None):
        """ListInstancesStatusResponse

        The model defined in huaweicloud sdk

        :param statics: 统计信息。
        :type statics: list[:class:`huaweicloudsdkworkspace.v2.InstanceStatusStatistics`]
        """
        
        super(ListInstancesStatusResponse, self).__init__()

        self._statics = None
        self.discriminator = None

        if statics is not None:
            self.statics = statics

    @property
    def statics(self):
        """Gets the statics of this ListInstancesStatusResponse.

        统计信息。

        :return: The statics of this ListInstancesStatusResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.InstanceStatusStatistics`]
        """
        return self._statics

    @statics.setter
    def statics(self, statics):
        """Sets the statics of this ListInstancesStatusResponse.

        统计信息。

        :param statics: The statics of this ListInstancesStatusResponse.
        :type statics: list[:class:`huaweicloudsdkworkspace.v2.InstanceStatusStatistics`]
        """
        self._statics = statics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstancesStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkworkspace-3.1.155-py2.py3-none-any.whl: huaweicloudsdkworkspace/v2/model/list_instances_status_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListInstancesStatusResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'statics': 'list[InstanceStatusStatistics]'
    }

    attribute_map = {
        'statics': 'statics'
    }

    def __init__(self, statics=None):
        r"""ListInstancesStatusResponse

        The model defined in huaweicloud sdk

        :param statics: 统计信息。
        :type statics: list[:class:`huaweicloudsdkworkspace.v2.InstanceStatusStatistics`]
        """
        
        super(ListInstancesStatusResponse, self).__init__()

        self._statics = None
        self.discriminator = None

        if statics is not None:
            self.statics = statics

    @property
    def statics(self):
        r"""Gets the statics of this ListInstancesStatusResponse.

        统计信息。

        :return: The statics of this ListInstancesStatusResponse.
        :rtype: list[:class:`huaweicloudsdkworkspace.v2.InstanceStatusStatistics`]
        """
        return self._statics

    @statics.setter
    def statics(self, statics):
        r"""Sets the statics of this ListInstancesStatusResponse.

        统计信息。

        :param statics: The statics of this ListInstancesStatusResponse.
        :type statics: list[:class:`huaweicloudsdkworkspace.v2.InstanceStatusStatistics`]
        """
        self._statics = statics

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListInstancesStatusResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
